"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.dump = exports.setTableData = exports.setChartBubbles = exports.setChartVerticalLines = exports.setChartData = exports.setAttribute = exports.setPosition = exports.setText = exports.setSolidFill = void 0;
const xml_helper_1 = require("./xml-helper");
const modify_chart_1 = require("../modify/modify-chart");
const setSolidFill = (element) => {
    element
        .getElementsByTagName('a:solidFill')[0]
        .getElementsByTagName('a:schemeClr')[0]
        .setAttribute('val', 'accent6');
};
exports.setSolidFill = setSolidFill;
const setText = (text) => (element) => {
    element.getElementsByTagName('a:t')[0].firstChild.textContent = text;
};
exports.setText = setText;
// e.g. setPosition({x: 8000000, h:5000000})
const setPosition = (pos) => (element) => {
    const map = {
        x: { tag: 'a:off', attribute: 'x' },
        y: { tag: 'a:off', attribute: 'y' },
        w: { tag: 'a:ext', attribute: 'cx' },
        h: { tag: 'a:ext', attribute: 'cy' },
    };
    const parent = 'a:xfrm';
    Object.keys(pos).forEach((key) => {
        element
            .getElementsByTagName(parent)[0]
            .getElementsByTagName(map[key].tag)[0]
            .setAttribute(map[key].attribute, pos[key]);
    });
};
exports.setPosition = setPosition;
const setAttribute = (tagName, attribute, value, count) => (element) => {
    element
        .getElementsByTagName(tagName)[count || 0].setAttribute(attribute, String(value));
};
exports.setAttribute = setAttribute;
const setChartData = (data) => (element, chart, workbook) => {
    const slots = [];
    data.series.forEach((series, s) => {
        slots.push({
            index: s,
            series: series,
            targetCol: s + 1,
            type: 'defaultSeries',
        });
    });
    new modify_chart_1.ModifyChart(chart, workbook, data, slots).modify();
    // XmlHelper.dump(chart)
};
exports.setChartData = setChartData;
const setChartVerticalLines = (data) => (element, chart, workbook) => {
    const slots = [];
    slots.push({
        label: `Y-Values`,
        mapData: (point, category) => category.y,
        targetCol: 1,
    });
    data.series.forEach((series, s) => {
        slots.push({
            index: s,
            series: series,
            targetCol: s + 2,
            type: 'xySeries',
        });
    });
    new modify_chart_1.ModifyChart(chart, workbook, data, slots).modify();
};
exports.setChartVerticalLines = setChartVerticalLines;
const setChartBubbles = (data) => (element, chart, workbook) => {
    const slots = [];
    data.series.forEach((series, s) => {
        const colId = s * 3;
        slots.push({
            index: s,
            series: series,
            targetCol: colId + 1,
            type: 'customSeries',
            tag: 'c:xVal',
            mapData: (point) => point.x,
        });
        slots.push({
            label: `${series.label}-Y-Value`,
            index: s,
            series: series,
            targetCol: colId + 2,
            type: 'customSeries',
            tag: 'c:yVal',
            mapData: (point) => point.y,
            isStrRef: false,
        });
        slots.push({
            label: `${series.label}-Size`,
            index: s,
            series: series,
            targetCol: colId + 3,
            type: 'customSeries',
            tag: 'c:bubbleSize',
            mapData: (point) => point.size,
            isStrRef: false,
        });
    });
    new modify_chart_1.ModifyChart(chart, workbook, data, slots).modify();
};
exports.setChartBubbles = setChartBubbles;
const setTableData = (data) => (element) => {
    xml_helper_1.XmlHelper.dump(element);
};
exports.setTableData = setTableData;
const dump = (element) => {
    xml_helper_1.XmlHelper.dump(element);
};
exports.dump = dump;
//# sourceMappingURL=modify-helper.js.map